@@ -15,9 +15,6 @@ wbSheetData <- R6::R6Class(
     #' @field cc cc
     cc = NULL,
 
-    #' @field cc_out cc_out
-    cc_out = NULL,
-
     #' @description
     #' Creates a new `wbSheetData` object
     #' @return a `wbSheetData` object
@@ -37,16 +34,6 @@ wb_sheet_data <- function() {
 
 # helpers -----------------------------------------------------------------
 
-# Consider making some helpers for the cc stuff.
-
-empty_sheet_data_cc <- function(n) {
-  create_char_dataframe(
-    colnames = c("r", "row_r", "c_r", "c_s", "c_t", "c_cm", "c_ph", "c_vm",
-                 "v", "f", "f_t", "f_ref", "f_ca", "f_si", "is", "typ"),
-    n = n
-  )
-}
-
 empty_row_attr <- function(n) {
   create_char_dataframe(
     colnames = c("collapsed", "customFormat", "customHeight", "x14ac:dyDescent",
