@@ -4,36 +4,13 @@ test_that("class wbComment works", {
   expect_null(assert_comment(wb_comment()))
 })
 
-test_that("wb_comment and create_comment are the same except for the different defaults", {
-  expect_warning(c1 <- create_comment("x1", author = ""), "deprecated")
-  c1_wb <- wb_comment("x1", visible = TRUE, author = "")
-  expect_equal(c1, c1_wb)
-  # create_comment drops multiple widths and heights silently.
-  # wb_comment errors in this case
-  expect_warning(create_comment(text = "x", author = "", width = c(1, 2)), "deprecated")
-  expect_error(wb_comment(text = "x", author = "", width = c(1, 2)), "width must be a single")
-
-})
-
-test_that("create_comment() works", {
+test_that("wb_comment() works", {
   # error checking
-  expect_warning(create_comment("hi", width = 1), "deprecated")
-  expect_warning(create_comment("hi", width = 1L), "deprecated")
-  expect_warning(create_comment("hi", width = c(1, 2)), "deprecated")
-  expect_warning(create_comment("hi", width = 1:2), "deprecated")
   expect_error(wb_comment("hi", width = 1:2), regexp = "width must be a")
 
-  expect_warning(create_comment("hi", height = 1), "deprecated")
-  expect_warning(create_comment("hi", height = 1L), "deprecated")
-  expect_warning(create_comment("hi", height = 1:2), "deprecated")
   expect_error(wb_comment("hi", height = 1:2))
-  expect_warning(expect_error(create_comment("hi", visible = NULL)), "deprecated")
-  expect_warning(expect_error(create_comment("hi", visible = c(TRUE, FALSE))), "deprecated")
 
-  expect_warning(expect_error(create_comment("hi", author = 1)), "deprecated")
-  expect_warning(expect_error(create_comment("hi", author = c("a", "a"))), "deprecated")
-
-  expect_warning(expect_s3_class(create_comment("Hello"), "wbComment"), "deprecated")
+  expect_error(wb_comment(text = "x", author = "", width = c(1, 2)), "width must be a single")
 })
 
 
@@ -97,7 +74,7 @@ test_that("load comments", {
   unlink(tempd, recursive = TRUE)
 
   ## add a new comment to a workbook that has comments
-  expect_warning(c1 <- create_comment(text = "this is a comment", author = ""), "deprecated")
+  c1 <- wb_comment(text = "this is a comment", author = "")
   expect_silent(wb$add_comment(5, dims = "B10", comment = c1))
 
   wb$save(temp)
@@ -113,7 +90,7 @@ test_that("load comments", {
 
 test_that("wb_add_comment", {
 
-  expect_warning(c1 <- create_comment(text = "this is a comment", author = ""), "deprecated")
+  c1 <- wb_comment(text = "this is a comment", author = "")
 
   wb <- wb_workbook()$add_worksheet()$add_comment(dims = "A1", comment = c1)
 
@@ -155,7 +132,7 @@ test_that("wb_add_comment() works without supplying a wbComment object.", {
 
 test_that("wb_remove_comment", {
 
-  expect_warning(c1 <- create_comment(text = "this is a comment", author = ""), "deprecated")
+  c1 <- wb_comment(text = "this is a comment", author = "")
   wb <- wb_workbook()$
     add_worksheet()$
     add_comment(dims = "A1", comment = c1)$
@@ -178,10 +155,8 @@ test_that("wb_remove_comment", {
 
 test_that("print comment", {
 
-  expect_warning(
-    c2 <- create_comment(text = "this is another comment",
-                       author = "Marco Polo"),
-    "deprecated")
+  c2 <- wb_comment(text = "this is another comment",
+                   author = "Marco Polo")
   got <- capture_output(print(c2), print = TRUE)
   exp <- "Author: Marco Polo\nText:\n Marco Polo:\nthis is another comment\n\nStyle:\n\n\n\n\nFont name: Aptos Narrow\nFont size: 11\nFont color: #000000\n\n"
   expect_equal(got, exp)
@@ -191,7 +166,7 @@ test_that("print comment", {
 test_that("removing comment sheet works", {
 
   temp <- temp_xlsx()
-  expect_warning(c1 <- create_comment(text = "this is a comment", author = ""), "deprecated")
+  c1 <- wb_comment(text = "this is a comment", author = "")
 
   wb <- wb_workbook()$
     add_worksheet("Sheet 1")$
@@ -207,7 +182,7 @@ test_that("fmt_txt in comment", {
 
   tmp <- temp_xlsx()
   txt <- fmt_txt("Hello ", bold = TRUE) + fmt_txt("World")
-  expect_warning(c1 <- create_comment(text = txt, author = "bla"), "deprecated")
+  c1 <- wb_comment(text = txt, author = "bla")
 
   wb <- wb_workbook()$add_worksheet()$add_comment(dims = "B10", comment = c1)
   expect_silent(wb$save(tmp))
@@ -403,7 +378,7 @@ test_that("wb_get_comment works", {
   expect_equal(exp, got)
 
   wb$remove_comment(dims = "B2")
-  expect_equal(NULL, wb$get_comment(dims = "B2"))
+  expect_equal(list(), wb$get_comment(dims = "B2"))
 
   wb$add_comment(
     dims = "B2",
@@ -412,3 +387,35 @@ test_that("wb_get_comment works", {
   got <- wb$get_comment(dims = "B2")
   expect_equal(1L, nrow(got))
 })
+
+test_that("removing comment from second sheet works", {
+
+  temp <- temp_xlsx()
+
+  c1 <- wb_comment(text = "this is a comment", author = "")
+
+  wb <- wb_workbook()$
+    add_worksheet("Sheet 1")$
+    add_worksheet("Sheet 2")$
+    add_comment(dims = "B10", comment = c1)$
+    remove_comment(dims = "B10")
+
+  expect_silent(wb$save(temp))
+
+  wb <- wb_workbook()$
+    add_worksheet("Sheet 1")$
+    add_worksheet("Sheet 2")$
+    add_comment(dims = "B10", comment = c1)$
+    add_comment(dims = "D10", comment = c1)$
+    add_comment(dims = "B12", comment = c1)
+
+  wb$remove_comment(sheet = "Sheet 2", dims = "B10")
+  wb$remove_comment(sheet = "Sheet 2", dims = "D10")
+  expect_warning(wb$remove_comment(sheet = "Sheet 2", dims = "G12"), "no comment to remove")
+  wb$remove_comment(sheet = "Sheet 2", dims = "B12")
+
+  expect_silent(wb$save(temp))
+  expect_equal(list(), wb$comments)
+  expect_equal(list(), wb$vml)
+
+})
