@@ -972,3 +972,46 @@ test_that("adding bg_color and diagonal borders work", {
   expect_equal(exp, got)
 
 })
+
+test_that("adding borders works", {
+  wb <- wb_workbook()$add_worksheet()
+  wb$add_data(x = matrix(8 * 10, 10, 8), col_names = FALSE)
+  wb$add_fill(dims = "A1:D5", color = wb_color("blue"))
+  wb$add_fill(dims = "A6:D10", color = wb_color("red"))
+  wb$add_fill(dims = "E1:H5", color = wb_color("green"))
+  wb$add_fill(dims = "E6:H10", color = wb_color("white"))
+
+  exp <- c(A1 = "1", B1 = "1", C1 = "1", D1 = "1", E1 = "3", F1 = "3",
+           G1 = "3", H1 = "3", A2 = "1", B2 = "1", C2 = "1", D2 = "1", E2 = "3",
+           F2 = "3", G2 = "3", H2 = "3", A3 = "1", B3 = "1", C3 = "1", D3 = "1",
+           E3 = "3", F3 = "3", G3 = "3", H3 = "3", A4 = "1", B4 = "1", C4 = "1",
+           D4 = "1", E4 = "3", F4 = "3", G4 = "3", H4 = "3", A5 = "1", B5 = "1",
+           C5 = "1", D5 = "1", E5 = "3", F5 = "3", G5 = "3", H5 = "3", A6 = "2",
+           B6 = "2", C6 = "2", D6 = "2", E6 = "4", F6 = "4", G6 = "4", H6 = "4",
+           A7 = "2", B7 = "2", C7 = "2", D7 = "2", E7 = "4", F7 = "4", G7 = "4",
+           H7 = "4", A8 = "2", B8 = "2", C8 = "2", D8 = "2", E8 = "4", F8 = "4",
+           G8 = "4", H8 = "4", A9 = "2", B9 = "2", C9 = "2", D9 = "2", E9 = "4",
+           F9 = "4", G9 = "4", H9 = "4", A10 = "2", B10 = "2", C10 = "2",
+           D10 = "2", E10 = "4", F10 = "4", G10 = "4", H10 = "4")
+  got <- wb$get_cell_style(dims = "A1:H10")
+  expect_equal(exp, got)
+
+  wb$add_border(dims = "A1:H10")
+  exp <- c(A1 = "5", B1 = "13", C1 = "13", D1 = "13", E1 = "14", F1 = "14",
+           G1 = "14", H1 = "6", A2 = "9", B2 = "17", C2 = "17", D2 = "17",
+           E2 = "18", F2 = "18", G2 = "18", H2 = "11", A3 = "9", B3 = "17",
+           C3 = "17", D3 = "17", E3 = "18", F3 = "18", G3 = "18", H3 = "11",
+           A4 = "9", B4 = "17", C4 = "17", D4 = "17", E4 = "18", F4 = "18",
+           G4 = "18", H4 = "11", A5 = "9", B5 = "17", C5 = "17", D5 = "17",
+           E5 = "18", F5 = "18", G5 = "18", H5 = "11", A6 = "10", B6 = "19",
+           C6 = "19", D6 = "19", E6 = "20", F6 = "20", G6 = "20", H6 = "12",
+           A7 = "10", B7 = "19", C7 = "19", D7 = "19", E7 = "20", F7 = "20",
+           G7 = "20", H7 = "12", A8 = "10", B8 = "19", C8 = "19", D8 = "19",
+           E8 = "20", F8 = "20", G8 = "20", H8 = "12", A9 = "10", B9 = "19",
+           C9 = "19", D9 = "19", E9 = "20", F9 = "20", G9 = "20", H9 = "12",
+           A10 = "7", B10 = "15", C10 = "15", D10 = "15", E10 = "16", F10 = "16",
+           G10 = "16", H10 = "8")
+  got <- wb$get_cell_style(dims = "A1:H10")
+  expect_equal(exp, got)
+
+})
